@@ -1,4 +1,4 @@
-# $Id: kqb_parser.py 141 2008-08-30 21:31:42Z mtnyogi $
+# $Id: kqb_parser.py 208 2009-03-25 20:17:03Z mtnyogi $
 # coding=utf-8
 # 
 # Copyright © 2008 Bruce Frederiksen
@@ -54,6 +54,7 @@ class kqb_parser(object):
         ) [ \t\f\r\v]* (?: \#.* )? ''', re.UNICODE | re.VERBOSE)
     pushed_token = None
     def __init__(self, f):
+        # f needs readline() and name.
         self.f = f
         self.lineno = 0
         self.line = ''
@@ -284,7 +285,7 @@ class kqb_parser(object):
             if next_token == 'regexp' and token == 'str':
                 return qa_helpers.regexp(next_value, value)
             if next_token == 'equal':
-                return qa_helpers.map(self.parse_simple_match(), value)
+                return qa_helpers.qmap(self.parse_simple_match(), value)
             if next_token == 'hyphen' and token == 'number':
                 final_token, final_value = self.get_token()
                 if final_token == 'number':
@@ -316,13 +317,13 @@ class kqb_parser(object):
             >>> do(r'/reg\exp/ bob')
             <regexp /reg\exp/>
             >>> do(r'"msg"/reg\exp/ bob')
-            <regexp "msg"/reg\exp/>
+            <regexp 'msg'/reg\exp/>
             >>> do(r'[prompt]/reg\exp/ bob')
             <regexp [prompt]/reg\exp/>
             >>> do(r'"msg"[prompt]/reg\exp/ bob')
-            <regexp "msg"[prompt]/reg\exp/>
+            <regexp 'msg'[prompt]/reg\exp/>
             >>> do(r"44 = id")
-            <map 44 = 'id'>
+            <qmap 44 = 'id'>
             >>> do(r"-5 bob")
             slice(None, 5, None)
             >>> do(r"0-5 bob")
@@ -367,7 +368,7 @@ class kqb_parser(object):
             ...    alt, review = p.parse_alternatives()
             ...    for tag, msg in alt:
             ...        print '%s: %s' % (repr(tag), repr(msg.template))
-            ...    for key, msg in sorted(review, key=lambda x: x[0]):
+            ...    for key, msg in sorted(review, key=lambda x: repr(x[0])):
             ...        print repr(key), '!', repr(msg.template)
             >>> do(r"""
             ...     1: hi mom
@@ -429,7 +430,7 @@ class kqb_parser(object):
             ...    ans.name = 'StringIO'
             ...    p = kqb_parser(ans)
             ...    review = p.parse_review()
-            ...    for key, msg in sorted(review, key=lambda x: x[0]):
+            ...    for key, msg in sorted(review, key=lambda x: repr(x[0])):
             ...        print repr(key), '!', repr(msg.template)
             >>> do(r"""
             ...     1 ! hi mom
@@ -439,9 +440,9 @@ class kqb_parser(object):
             ...     3-5! nope, this is just 44
             ... next
             ... """)
+            'bob' ! u'yep this is bob'
             1 ! u'hi mom\nhow are you?\n! Just reward!'
             slice(3, 5, None) ! u'nope, this is just 44'
-            'bob' ! u'yep this is bob'
         '''
         if self.column >= len(self.line):
             self.readline()
