@@ -1,4 +1,4 @@
-# $Id: scanner.py 162 2008-12-25 18:56:46Z mtnyogi $
+# $Id: scanner.py 185 2009-03-06 19:02:16Z mtnyogi $
 # coding=utf-8
 # 
 # Copyright © 2007-2008 Bruce Frederiksen
@@ -27,7 +27,7 @@
 from __future__ import with_statement
 import string
 import os, os.path
-from ply import lex
+from pyke.krb_compiler.ply import lex
 
 debug=0
 
